@@ -235,6 +235,8 @@ typedef enum {
     XML_DTD_UNKNOWN_ID, /* 536 */
     XML_DTD_UNKNOWN_NOTATION, /* 537 */
     XML_DTD_STANDALONE_DEFAULTED, /* 538 */
+    XML_DTD_XMLID_VALUE, /* 539 */
+    XML_DTD_XMLID_TYPE, /* 540 */
     XML_HTML_STRUCURE_ERROR = 800,
     XML_HTML_UNKNOWN_TAG, /* 801 */
     XML_RNGP_ANYNAME_ATTR_ANCESTOR = 1000,
@@ -544,6 +546,34 @@ typedef enum {
     XML_SCHEMAP_INCLUDE_SCHEMA_NOT_URI, /* 1769 */
     XML_SCHEMAP_INCLUDE_SCHEMA_NO_URI, /* 1770 */
     XML_SCHEMAP_NOT_SCHEMA, /* 1771 */
+    XML_SCHEMAP_UNKNOWN_MEMBER_TYPE, /* 1772 */
+    XML_SCHEMAP_INVALID_ATTR_USE, /* 1773 */
+    XML_SCHEMAP_RECURSIVE, /* 1774 */
+    XML_SCHEMAP_SUPERNUMEROUS_LIST_ITEM_TYPE, /* 1775 */
+    XML_SCHEMAP_INVALID_ATTR_COMBINATION, /* 1776 */
+    XML_SCHEMAP_INVALID_ATTR_INLINE_COMBINATION, /* 1777 */
+    XML_SCHEMAP_MISSING_SIMPLETYPE_CHILD, /* 1778 */
+    XML_SCHEMAP_INVALID_ATTR_NAME, /* 1779 */
+    XML_SCHEMAP_REF_AND_CONTENT, /* 1780 */
+    XML_SCHEMAP_CT_PROPS_CORRECT_1, /* 1781 */
+    XML_SCHEMAP_CT_PROPS_CORRECT_2, /* 1782 */
+    XML_SCHEMAP_CT_PROPS_CORRECT_3, /* 1783 */
+    XML_SCHEMAP_CT_PROPS_CORRECT_4, /* 1784 */
+    XML_SCHEMAP_CT_PROPS_CORRECT_5, /* 1785 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_1, /* 1786 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_2_1_1, /* 1787 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_2_1_2, /* 1788 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_2_2, /* 1789 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_3, /* 1790 */
+    XML_SCHEMAP_WILDCARD_INVALID_NS_MEMBER, /* 1791 */
+    XML_SCHEMAP_INTERSECTION_NOT_EXPRESSIBLE, /* 1792 */
+    XML_SCHEMAP_UNION_NOT_EXPRESSIBLE, /* 1793 */
+    XML_SCHEMAP_SRC_IMPORT_3_1, /* 1794 */
+    XML_SCHEMAP_SRC_IMPORT_3_2, /* 1795 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_4_1, /* 1796 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_4_2, /* 1797 */
+    XML_SCHEMAP_DERIVATION_OK_RESTRICTION_4_3, /* 1798 */
+    XML_SCHEMAP_COS_CT_EXTENDS_1_3, /* 1799 */
     XML_SCHEMAV_NOROOT = 1800,
     XML_SCHEMAV_UNDECLAREDELEM, /* 1801 */
     XML_SCHEMAV_NOTTOPLEVEL, /* 1802 */
@@ -567,7 +597,28 @@ typedef enum {
     XML_SCHEMAV_ATTRINVALID, /* 1820 */
     XML_SCHEMAV_VALUE, /* 1821 */
     XML_SCHEMAV_FACET, /* 1822 */
-    XML_XPTR_UNKNOWN_SCHEME = 1900,
+    XML_SCHEMAV_CVC_DATATYPE_VALID_1_2_1, /* 1823 */
+    XML_SCHEMAV_CVC_DATATYPE_VALID_1_2_2, /* 1824 */
+    XML_SCHEMAV_CVC_DATATYPE_VALID_1_2_3, /* 1825 */
+    XML_SCHEMAV_CVC_TYPE_3_1_1, /* 1826 */
+    XML_SCHEMAV_CVC_TYPE_3_1_2, /* 1827 */
+    XML_SCHEMAV_CVC_FACET_VALID, /* 1828 */
+    XML_SCHEMAV_CVC_LENGTH_VALID, /* 1829 */
+    XML_SCHEMAV_CVC_MINLENGTH_VALID, /* 1830 */
+    XML_SCHEMAV_CVC_MAXLENGTH_VALID, /* 1831 */
+    XML_SCHEMAV_CVC_MININCLUSIVE_VALID, /* 1832 */
+    XML_SCHEMAV_CVC_MAXINCLUSIVE_VALID, /* 1833 */
+    XML_SCHEMAV_CVC_MINEXCLUSIVE_VALID, /* 1834 */
+    XML_SCHEMAV_CVC_MAXEXCLUSIVE_VALID, /* 1835 */
+    XML_SCHEMAV_CVC_TOTALDIGITS_VALID, /* 1836 */
+    XML_SCHEMAV_CVC_FRACTIONDIGITS_VALID, /* 1837 */
+    XML_SCHEMAV_CVC_PATTERN_VALID, /* 1838 */
+    XML_SCHEMAV_CVC_ENUMERATION_VALID, /* 1839 */
+    XML_SCHEMAV_CVC_COMPLEX_TYPE_2_1, /* 1840 */
+    XML_SCHEMAV_CVC_COMPLEX_TYPE_2_2, /* 1841 */
+    XML_SCHEMAV_CVC_COMPLEX_TYPE_2_3, /* 1842 */
+    XML_SCHEMAV_CVC_COMPLEX_TYPE_2_4, /* 1843 */
+    XML_XPTR_UNKNOWN_SCHEME = 1900, 
     XML_XPTR_CHILDSEQ_START, /* 1901 */
     XML_XPTR_EVAL_FAILED, /* 1902 */
     XML_XPTR_EXTRA_OBJECTS, /* 1903 */
@@ -580,7 +631,77 @@ typedef enum {
     XML_FTP_ACCNT, /* 2002 */
     XML_HTTP_URL_SYNTAX = 2020,
     XML_HTTP_USE_IP, /* 2021 */
-    XML_HTTP_UNKNOWN_HOST /* 2022 */
+    XML_HTTP_UNKNOWN_HOST, /* 2022 */
+    XML_SCHEMAP_SRC_SIMPLE_TYPE_1 = 3000,
+    XML_SCHEMAP_SRC_SIMPLE_TYPE_2, /* 3001 */
+    XML_SCHEMAP_SRC_SIMPLE_TYPE_3, /* 3002 */
+    XML_SCHEMAP_SRC_SIMPLE_TYPE_4, /* 3003 */
+    XML_SCHEMAP_SRC_RESOLVE, /* 3004 */ 
+    XML_SCHEMAP_SRC_RESTRICTION_BASE_OR_SIMPLETYPE, /* 3005 */
+    XML_SCHEMAP_SRC_LIST_ITEMTYPE_OR_SIMPLETYPE, /* 3006 */
+    XML_SCHEMAP_SRC_UNION_MEMBERTYPES_OR_SIMPLETYPES, /* 3007 */
+    XML_SCHEMAP_ST_PROPS_CORRECT_1, /* 3008 */
+    XML_SCHEMAP_ST_PROPS_CORRECT_2, /* 3009 */
+    XML_SCHEMAP_ST_PROPS_CORRECT_3, /* 3010 */     
+    XML_SCHEMAP_COS_ST_RESTRICTS_1_1, /* 3011 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_1_2, /* 3012 */    
+    XML_SCHEMAP_COS_ST_RESTRICTS_1_3_1, /* 3013 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_1_3_2, /* 3014 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_1, /* 3015 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_1_1, /* 3016 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_1_2, /* 3017 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_2_1, /* 3018 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_2_2, /* 3019 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_2_3, /* 3020 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_2_4, /* 3021 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_2_3_2_5, /* 3022 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_1, /* 3023 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_1, /* 3024 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_1_2, /* 3025 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_2_2, /* 3026 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_2_1, /* 3027 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_2_3, /* 3028 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_2_4, /* 3029 */
+    XML_SCHEMAP_COS_ST_RESTRICTS_3_3_2_5, /* 3030 */
+    XML_SCHEMAP_COS_ST_DERIVED_OK_2_1, /* 3031 */ 
+    XML_SCHEMAP_COS_ST_DERIVED_OK_2_2, /* 3032 */
+    XML_SCHEMAP_S4S_ELEM_NOT_ALLOWED, /* 3033 */
+    XML_SCHEMAP_S4S_ELEM_MISSING, /* 3034 */
+    XML_SCHEMAP_S4S_ATTR_NOT_ALLOWED, /* 3035 */
+    XML_SCHEMAP_S4S_ATTR_MISSING, /* 3036 */
+    XML_SCHEMAP_S4S_ATTR_INVALID_VALUE, /* 3037 */
+    XML_SCHEMAP_SRC_ELEMENT_1, /* 3038 */
+    XML_SCHEMAP_SRC_ELEMENT_2_1, /* 3039 */
+    XML_SCHEMAP_SRC_ELEMENT_2_2, /* 3040 */
+    XML_SCHEMAP_SRC_ELEMENT_3, /* 3041 */
+    XML_SCHEMAP_P_PROPS_CORRECT_1, /* 3042 */
+    XML_SCHEMAP_P_PROPS_CORRECT_2_1, /* 3043 */
+    XML_SCHEMAP_P_PROPS_CORRECT_2_2, /* 3044 */
+    XML_SCHEMAP_E_PROPS_CORRECT_2, /* 3045 */
+    XML_SCHEMAP_E_PROPS_CORRECT_3, /* 3046 */
+    XML_SCHEMAP_E_PROPS_CORRECT_4, /* 3047 */
+    XML_SCHEMAP_E_PROPS_CORRECT_5, /* 3048 */
+    XML_SCHEMAP_E_PROPS_CORRECT_6, /* 3049 */
+    XML_SCHEMAP_SRC_INCLUDE, /* 3050 */    
+    XML_SCHEMAP_SRC_ATTRIBUTE_1, /* 3051 */
+    XML_SCHEMAP_SRC_ATTRIBUTE_2, /* 3052 */
+    XML_SCHEMAP_SRC_ATTRIBUTE_3_1, /* 3053 */
+    XML_SCHEMAP_SRC_ATTRIBUTE_3_2, /* 3054 */
+    XML_SCHEMAP_SRC_ATTRIBUTE_4, /* 3055 */
+    XML_SCHEMAP_NO_XMLNS, /* 3056 */
+    XML_SCHEMAP_NO_XSI, /* 3057 */
+    XML_SCHEMAP_COS_VALID_DEFAULT_1,
+    XML_SCHEMAP_COS_VALID_DEFAULT_2_1,
+    XML_SCHEMAP_COS_VALID_DEFAULT_2_2_1,
+    XML_SCHEMAP_COS_VALID_DEFAULT_2_2_2,
+    XML_SCHEMAP_CVC_SIMPLE_TYPE,
+    XML_SCHEMAP_COS_CT_EXTENDS_1_1,
+    XML_SCHEMAP_SRC_IMPORT_1_1,
+    XML_SCHEMAP_SRC_IMPORT_1_2,
+    XML_SCHEMAP_SRC_IMPORT_2,
+    XML_SCHEMAP_SRC_IMPORT_2_1,
+    XML_SCHEMAP_SRC_IMPORT_2_2
+    
 } xmlParserErrors;
 
 /**
